#ifndef JOHNSMTP__H_
#define JOHNSMTP__H_

#ifdef JCL_DO_EXPORT
#define JCL_EXPORT __declspec (dllexport) 
#else
#define JCL_EXPORT
#endif

// "C" interface

// Return values from SendMail or CreateAndSendMail
#define ERR_JSMTP_SUCCESS		  0			// Success!
#define	ERR_JSMTP_EMAILNOTREADY	  1		    // Fields not filled out
#define	ERR_JSMTP_NOSERVERCONNECT 2		    // Connect failed, bad server field? server down?
											// User cancelled?
#define ERR_JSMTP_INVALIDDOMAIN	  3			// Handshake "HELO" failed.  Bad domain field?
											// Sometimes an ESMTP server refusing the handshake
											// will cause this error as well (e.g. smtp.ix.netcom.com).
#define ERR_JSMTP_INVALIDSENDER   4			// Sender field invalid.  Bad address?
#define	ERR_JSMTP_NOVALIDRECIPS	  5			// None of the recipients were valid
											// Note that if some were, mail could still
											// be sent to remainder
#define ERR_JSMTP_DATASENDREADYERR 6		// Server not ready to receive mail data.
#define ERR_JSMTP_DATASENDFAILED   7		// Server reported error after 
											// receiving mail data
#ifdef __cplusplus
extern "C" {
#endif

//	Set calls.  One way to send mail is to call several of these set calls, then
//  call SendMail.  Calls marked with an asterisk are required.  For a single call that 
//  sets these values and then sends, see CreateAndSendMail.

JCL_EXPORT
void SetRecipients(LPCSTR szRecipients);	// * Single recipient "johnl@calweb.com" 
											//   or (space-trimmed) comma-separated list 

JCL_EXPORT
void SetSender(LPCSTR szSender);			// *  email address of sender, e.g., "jdoe@best.com"

JCL_EXPORT
void SetMailData(LPCSTR szMailData);		// *  Text of mail.

JCL_EXPORT																							   
void SetServerDirect(LPCSTR szServer);		// *  Sender's SMTP server, 
											//    e.g. "smtp.best.com"
JCL_EXPORT
void SetDomain(LPCSTR szDomain);			// *  Sender's domain 
											//    e.g. "best.com"
JCL_EXPORT
void SetSubject(LPCSTR szSubject);			// Optional subject line.

JCL_EXPORT
int	SendMail();								// Send the mail, based on the set calls above.

JCL_EXPORT
int	CreateAndSendMail(					    // Creates and sends mail in one step.  
	LPCSTR szRecipients, 					// Required, same as "SetRecipients"
	LPCSTR szSender, 						// Required, same as "SetSender"
	LPCSTR szMailData, 						// Required, same as "SetMailData" 
	LPCSTR szSubject,  						// Subject, or NULL.  Optional.
	LPCSTR szServer, 						// Server, or, if NULL, will be "smtp.xxx.yyy",
											// 		based on sender's e-mail as "jdoe@xxx.yyy"
	LPCSTR szDomain);						// Domain, or, if NULL, will be "xxx.yyy"
											// 		based on sender's e-mail as "jdoe@xxx.yyy"
#ifdef __cplusplus
}
#endif


#endif // JOHNSMTP

